@@ -10,7 +10,8 @@
 #ifndef KOPREFSDIALOGGROUPWARESCHEDULING_H
 #define KOPREFSDIALOGGROUPWARESCHEDULING_H
 #include "kprefsdialog.h"
-namespace Ui {
+namespace Ui
+{
 class KOGroupwarePrefsPage;
 }
 
@@ -18,7 +19,7 @@ class KOPrefsDialogGroupwareScheduling : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    KOPrefsDialogGroupwareScheduling(QWidget *parent);
+    explicit KOPrefsDialogGroupwareScheduling(QWidget *parent);
     ~KOPrefsDialogGroupwareScheduling() override;
 
 protected:
