@@ -12,14 +12,13 @@
 #include <KLocalizedString>
 #include <QVBoxLayout>
 #ifdef WITH_KUSERFEEDBACK
-#include <KUserFeedback/FeedbackConfigWidget>
 #include "userfeedback/userfeedbackmanager.h"
+#include <KUserFeedback/FeedbackConfigWidget>
 #endif
 
 #ifdef WITH_KUSERFEEDBACK
 
-extern "C"
-{
+extern "C" {
 Q_DECL_EXPORT KCModule *create_korguserfeeback(QWidget *parent, const char *)
 {
     return new KOPrefsUserFeedBack(parent);
@@ -37,7 +36,7 @@ KOPrefsUserFeedBack::KOPrefsUserFeedBack(QWidget *parent, const QVariantList &ar
                                        i18n("(c) 2020 Laurent Montel"));
     about->addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
     setAboutData(about);
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins({});
 
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
