@@ -47,13 +47,14 @@ public:
         QVector<Ptr> children;
         Node *parent = nullptr;
         ReparentingModel &personModel;
-        bool mIsSourceNode = false;
+        const bool mIsSourceNode = false;
     };
 
     struct NodeManager {
         using Ptr = QSharedPointer<NodeManager>;
 
-        NodeManager(ReparentingModel &m) : model(m)
+        NodeManager(ReparentingModel &m)
+            : model(m)
         {
         }
 
@@ -67,7 +68,7 @@ public:
     private:
         friend class ReparentingModel;
 
-        //Allows the implementation to create proxy nodes as necessary
+        // Allows the implementation to create proxy nodes as necessary
         virtual void checkSourceIndex(const QModelIndex & /* sourceIndex */)
         {
         }
