@@ -17,13 +17,10 @@ class KItemIconCheckCombo : public KPIM::KCheckComboBox
 {
     Q_OBJECT
 public:
-    enum ViewType {
-        AgendaType = 0,
-        MonthType
-    };
+    enum ViewType { AgendaType = 0, MonthType };
 
     explicit KItemIconCheckCombo(ViewType viewType, QWidget *parent = nullptr);
-    ~KItemIconCheckCombo();
+    ~KItemIconCheckCombo() override;
 
     void setCheckedIcons(const QSet<EventViews::EventView::ItemIcon> &icons);
     Q_REQUIRED_RESULT QSet<EventViews::EventView::ItemIcon> checkedIcons() const;
